@@ -3,12 +3,6 @@ import importlib
 
 from lesscode.db.base_connection_pool import BaseConnectionPool
 
-elasticsearch = None
-try:
-    elasticsearch = importlib.import_module("elasticsearch")
-except ImportError as e:
-    raise Exception(f"elasticsearch is not exist,run:pip install elasticsearch==7.15.2")
-
 
 class ElasticsearchPool(BaseConnectionPool):
     """
@@ -18,13 +12,16 @@ class ElasticsearchPool(BaseConnectionPool):
     async def create_pool(self):
         """
         创建elasticsearch 异步连接池
-        :param conn_info: 连接信息
         :return:
         """
         info = self.conn_info
         if info.async_enable:
             host_str = info.host.split(",")
             hosts = [f"http://{info.user}:{info.password}@{host}:{info.port}" for host in host_str]
+            try:
+                elasticsearch = importlib.import_module("elasticsearch")
+            except ImportError:
+                raise Exception(f"elasticsearch is not exist,run:pip install elasticsearch==7.15.2")
             pool = elasticsearch.AsyncElasticsearch(hosts=hosts)
             return pool
         else:
@@ -34,5 +31,9 @@ class ElasticsearchPool(BaseConnectionPool):
         info = self.conn_info
         host_str = info.host.split(",")
         hosts = [f"http://{info.user}:{info.password}@{host}:{info.port}" for host in host_str]
+        try:
+            elasticsearch = importlib.import_module("elasticsearch")
+        except ImportError:
+            raise Exception(f"elasticsearch is not exist,run:pip install elasticsearch==7.15.2")
         pool = elasticsearch.Elasticsearch(hosts)
         return pool
