@@ -79,6 +79,11 @@ class InitConnectionPool:
                                                             fromlist="NebulaPool")
                         # 执行用例
                         pool = clazz(conn_info).create_pool()
+                    elif conn_info.dialect == "redis-cluster":
+                        clazz = InitConnectionPool.getClass("lesscode.db.redis_cluster.redis_cluster_pool",
+                                                            fromlist="RedisClusterPool")
+                        # 执行用例
+                        pool = await clazz(conn_info).create_pool()
                     if pool:
                         options.database[conn_info.name] = (pool, conn_info)
 
@@ -147,6 +152,11 @@ class InitConnectionPool:
                                                             fromlist="NebulaPool")
                         # 执行用例
                         pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "redis-cluster":
+                        clazz = InitConnectionPool.getClass("lesscode.db.redis_cluster.redis_cluster_pool",
+                                                            fromlist="RedisClusterPool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
                     if pool:
                         options.database[conn_info.name] = (pool, conn_info)
 
