@@ -18,7 +18,7 @@ class MongodbPool(BaseConnectionPool):
         """
         try:
             motor = importlib.import_module("motor")
-        except ImportError as e:
+        except ImportError:
             raise Exception(f"motor is not exist,run:pip install motor==2.5.1")
         info = self.conn_info
         if info.async_enable:
@@ -40,7 +40,7 @@ class MongodbPool(BaseConnectionPool):
     def sync_create_pool(self):
         try:
             pymongo = importlib.import_module("pymongo")
-        except ImportError as e:
+        except ImportError:
             raise Exception(f"pymongo is not exist,run:pip install pymongo==3.13.0")
         info = self.conn_info
         host_str = info.host.split(",")
