@@ -1,4 +1,8 @@
+import warnings
+
+
 def alchemy_default_to_dict(params, data, repetition=False):
+    warnings.warn("此方法即将弃用，不推荐使用", DeprecationWarning)
     data_list = []
     key_list = []
     if repetition:
@@ -27,6 +31,7 @@ def alchemy_default_to_dict(params, data, repetition=False):
 
 
 def sqlalchemy_paging(Query, limit_number, offset_number):
+    warnings.warn("此方法即将弃用，不推荐使用", DeprecationWarning)
     data_list = Query.limit(limit_number).offset(offset_number).all()
     data_count = Query.count()
     return {"count": data_count, "dataSource": data_list}
