@@ -1,28 +1,20 @@
 # -*- coding: utf-8 -*-
 import importlib
-
-from tornado.options import options
-
 import logging
 import traceback
 
+from tornado.options import options
+
 from lesscode.db.page import Page
 from lesscode.utils.encryption_algorithm import AES
 
-try:
-    neo4j = importlib.import_module("neo4j")
-    neo4j_data = importlib.import_module("neo4j.data")
-    neo4j_graph = importlib.import_module("neo4j.graph")
-except ImportError as e:
-    raise Exception(f"neo4j is not exist,run:pip install neo4j==5.0.0")
-
 
 class Neo4jHelper:
     """
     Neo4j   数据库操作实现
     """
 
-    def __init__(self, pool, access=neo4j.READ_ACCESS):
+    def __init__(self, pool, access="READ"):
         """
         初始化sql工具
         :param pool: 连接池名称
@@ -1029,23 +1021,28 @@ def dict_str(data: dict):
     return string
 
 
-def node2dict(node: neo4j_graph.Node):
+def node2dict(node):
     return {"id": node.id, "labels": list(node.labels), "properties": node._properties}
 
 
-def relationship2dict(relationship: neo4j_graph.Relationship):
+def relationship2dict(relationship):
     return {"start_node": node2dict(relationship.start_node), "end_node": node2dict(relationship.end_node),
             "id": relationship.id,
             "type": relationship.type, "properties": relationship._properties}
 
 
-def path2dict(path: neo4j_graph.Path):
+def path2dict(path):
     return {"start_node": node2dict(path.start_node), "end_node": node2dict(path.end_node),
             "nodes": [node2dict(n) for n in path.nodes],
             "relationships": [relationship2dict(r) for r in path.relationships]}
 
 
-def parse_record(record: neo4j_data.Record, flag=True):
+def parse_record(record, flag=True):
+    try:
+        neo4j_data = importlib.import_module("neo4j.data")
+        neo4j_graph = importlib.import_module("neo4j.graph")
+    except ImportError:
+        raise Exception(f"neo4j is not exist,run:pip install neo4j==5.0.0")
     _record = {"node": [], "relationship": [], "path": [], "other": []}
     if isinstance(record, neo4j_data.Record):
         for rd in record:
