@@ -105,24 +105,27 @@ def covert_relationship_property(attr, attr_value):
 
 
 def query_set_to_dict(obj):
-    if hasattr(obj, "__mapper__"):
-        obj_dict = {}
-        mapper = obj.__mapper__
-        if hasattr(mapper, "attrs"):
-            attrs = mapper.attrs
-            for column, attr in attrs.items():
-                attr_value = getattr(obj, column)
-                value = covert_relationship_property(attr, attr_value)
-                if not value.__class__.__name__ == 'RelationshipProperty':
-                    obj_dict[column] = value
+    if obj:
+        if hasattr(obj, "__mapper__"):
+            obj_dict = {}
+            mapper = obj.__mapper__
+            if hasattr(mapper, "attrs"):
+                attrs = mapper.attrs
+                for column, attr in attrs.items():
+                    attr_value = getattr(obj, column)
+                    value = covert_relationship_property(attr, attr_value)
+                    if not value.__class__.__name__ == 'RelationshipProperty':
+                        obj_dict[column] = value
 
-        return obj_dict
-    elif hasattr(obj, "keys"):
-        return {key: getattr(obj, key) for key in obj.keys()}
-    elif hasattr(obj, "_asdict"):
-        return obj._asdict()
+            return obj_dict
+        elif hasattr(obj, "keys"):
+            return {key: getattr(obj, key) for key in obj.keys()}
+        elif hasattr(obj, "_asdict"):
+            return obj._asdict()
+        else:
+            return dict(obj)
     else:
-        return dict(obj)
+        return obj
 
 
 def query_set_to_list(query_set):
