@@ -1,6 +1,4 @@
-import inspect
-
-from lesscode.utils.doc.interface_doc_handler import swagger_json_project, swagger_json_class, python_column_type_dict
+from lesscode.utils.doc.interface_doc_handler import swagger_json_project
 from lesscode.web.base_handler import BaseHandler
 from lesscode.web.router_mapping import Handler, GetMapping
 from tornado.options import options
