@@ -5,12 +5,6 @@ import traceback
 
 from tornado.options import options
 
-pika = None
-try:
-    pika = importlib.import_module("pika")
-except ImportError as e:
-    raise Exception(f"pika is not exist,run:pip install pika==1.3.0")
-
 
 class RabbitMqHelper:
     def __init__(self, **kwargs):
@@ -36,6 +30,10 @@ class RabbitMqHelper:
             raise Exception("missing queue")
         self.exchange = kwargs.pop("exchange", None)
         exchange_kwargs = kwargs.pop("exchange_kwargs", {})
+        try:
+            pika = importlib.import_module("pika")
+        except ImportError as e:
+            raise Exception(f"pika is not exist,run:pip install pika==1.3.0")
         credentials = pika.PlainCredentials(username, password)
         self.connection = pika.BlockingConnection(
             pika.ConnectionParameters(host=host, port=port, credentials=credentials, **kwargs))
@@ -50,6 +48,10 @@ class RabbitMqHelper:
             message = message.encode("utf-8")
         elif not isinstance(message, bytes):
             raise Exception("message must be str or bytes")
+        try:
+            pika = importlib.import_module("pika")
+        except ImportError as e:
+            raise Exception(f"pika is not exist,run:pip install pika==1.3.0")
         res = self.channel.basic_publish(exchange=exchange, routing_key=self.queue, body=message,
                                          properties=pika.BasicProperties(
                                              delivery_mode=2
