@@ -7,7 +7,7 @@ from tornado.options import options
 
 
 def format_company_id_en(value, route_key):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     key = options.aes_key
     if route_key in ["core.patent", "core.patent_lite"]:
         for data in value.get("tags", {}).get("proposer_type", []):
@@ -24,7 +24,7 @@ def format_company_id_en(value, route_key):
 
 
 def format_es_param_result(r, param_list, is_need_decrypt_oralce, is_need_es_score, route_key):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     result_dict = {}
     format_company_id_en(r["_source"], route_key)
     if param_list and r["_source"]:
@@ -60,7 +60,7 @@ def format_es_param_result(r, param_list, is_need_decrypt_oralce, is_need_es_sco
 
 
 def es_condition_by_match_phrase(bool_list, column, param, slop=0):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if param:
         if isinstance(param, list):
             bool_list.append({
@@ -83,7 +83,7 @@ def es_condition_by_match_phrase(bool_list, column, param, slop=0):
 
 
 def es_condition_by_match(bool_list, column, param):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if param:
         if isinstance(param, list):
             bool_list.append({
@@ -104,7 +104,7 @@ def es_condition_by_match(bool_list, column, param):
 
 
 def es_condition_by_not_null(boo_must_list, column, param):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if param:
         boo_must_list.append({
             "exists": {
@@ -114,7 +114,7 @@ def es_condition_by_not_null(boo_must_list, column, param):
 
 
 def es_condition_by_range(bool_must_list, column, date_list, is_contain_end_date=False, is_contain_start_date=True):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if date_list:
         range_dict = {}
         if date_list[0]:
@@ -137,7 +137,7 @@ def es_condition_by_range(bool_must_list, column, date_list, is_contain_end_date
 
 
 def es_condition_by_terms(bool_must_list, column, param_list, is_need_decrypt_oralce=False):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if param_list:
         param_list = [i for i in param_list if i not in [None, "", "all"]]
         if is_need_decrypt_oralce:
@@ -155,13 +155,13 @@ def es_condition_by_terms(bool_must_list, column, param_list, is_need_decrypt_or
 
 
 def es_condition_by_wildcard(bool_list, column, param):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if param:
         bool_list.append({"wildcard": {column: f"*{param}*"}})
 
 
 def es_condition_by_exist(bool_must_list, param, is_exists="是"):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if param:
         if is_exists == "是" or is_exists == "true" or is_exists == True:
             bool_must_list.append({
@@ -183,7 +183,7 @@ def es_condition_by_exist(bool_must_list, param, is_exists="是"):
 
 
 def es_condition_by_exist_or_not(bool_must_list, param_dict):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if param_dict:
         for key in param_dict:
             if param_dict[key] in ["是", "true", True]:
@@ -206,7 +206,7 @@ def es_condition_by_exist_or_not(bool_must_list, param_dict):
 
 
 def es_condition_by_not_in(bool_must_list: list = None, column="", param_list=None):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if param_list:
         bool_must_list.append({
             "bool": {
@@ -220,7 +220,7 @@ def es_condition_by_not_in(bool_must_list: list = None, column="", param_list=No
 
 def es_condition_by_geo_shape(bool_must_list: list = None, column="", polygon=None, geo_type="MultiPolygon",
                               relation="intersects"):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if polygon:
         bool_must_list.append({
             "geo_shape": {
@@ -236,7 +236,7 @@ def es_condition_by_geo_shape(bool_must_list: list = None, column="", polygon=No
 
 
 def format_bool_must_and_should(bool_must_list, bool_should_more_list):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if bool_should_more_list:
         for bool_should in bool_should_more_list:
             bool_must_list.append({
@@ -247,7 +247,7 @@ def format_bool_must_and_should(bool_must_list, bool_should_more_list):
 
 
 def format_bool_must_and_must_not(bool_must_list, bool_must_not_more_list):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if bool_must_not_more_list:
         for bool_must_not in bool_must_not_more_list:
             bool_must_list.append({
@@ -258,7 +258,7 @@ def format_bool_must_and_must_not(bool_must_list, bool_must_not_more_list):
 
 
 def parse_es_sort_list(column=None, order=None):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if column and order:
         if order == "asc":
             sort_list = [
@@ -285,7 +285,7 @@ def parse_es_sort_list(column=None, order=None):
 
 
 def es_condition_by_geo_distance(bool_must_list: list = None, column="", geo_distance=None):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if geo_distance:
         bool_must_list.append({
             "geo_distance": {
@@ -299,7 +299,7 @@ def es_condition_by_geo_distance(bool_must_list: list = None, column="", geo_dis
 
 
 def es_mapping2dict(mapping):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     mapping_dict = dict()
 
     if isinstance(mapping, dict):
