@@ -1,8 +1,10 @@
 import logging
+import warnings
 from threading import Thread
 
 
 def calculate_common_pool(thread_list):
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     for j in thread_list:
         j.start()
     for t in thread_list:
@@ -11,6 +13,7 @@ def calculate_common_pool(thread_list):
 
 
 class MyThread(Thread):
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
 
     def __init__(self, target, args=(), kwargs=None):
         super(MyThread, self).__init__()
