@@ -4,7 +4,7 @@ from lesscode.utils.EsUtil import es_condition_by_terms, es_condition_by_wildcar
 
 
 def format_param_tag(bool_should_more_list, especial_tag_list):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     bool_should_list = []
     if especial_tag_list is not None:
         for tag in especial_tag_list:
