@@ -5,7 +5,7 @@ from lesscode.utils.common import get_value_from_dict
 
 
 def money_format(value, is_int=False):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     value = "%.2f" % float(value)
     components = str(value).split('.')
     if len(components) > 1:
@@ -23,14 +23,14 @@ def money_format(value, is_int=False):
 
 
 def get_value_by_key(data: dict, key: str = None):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode_charts包里", DeprecationWarning)
     if key:
         data = data.get(key)
     return data
 
 
 def get_data_by_deep_from_dict(data: dict, deep: int):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode_charts包里", DeprecationWarning)
     if not data:
         return {}
     result = {}
@@ -54,7 +54,7 @@ def dict2ring(data: dict, unit: str = "", second_unit: str = "", key: str = "cou
     :param title:图题
     :return:
     """
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode_charts包里", DeprecationWarning)
     total = 0
     for name, value in data.items():
         total += get_value_by_key(value, key)
@@ -92,7 +92,7 @@ def dict2columnar(data: dict, num: int, key_map: dict = None, title: str = "",
     :param default:获取不到内容时的默认数据
     :return:
     """
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode_charts包里", DeprecationWarning)
     first_keys = list(data.keys())
     result = {
         "title": title,
@@ -141,7 +141,7 @@ def list2table(title: str, head, data: list, column_keys: dict = None, index_dic
     :param head: 表头，支持dict和list ，实例1：{"企业名称": "name"},实例2：[{"企业名称": "name"}]
 
     """
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode_charts包里", DeprecationWarning)
     result = {
         "title": title,
         "columns": [],
@@ -183,7 +183,7 @@ def list2table(title: str, head, data: list, column_keys: dict = None, index_dic
 
 
 def convert(value, func):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode_utils包里", DeprecationWarning)
     return func(value)
 
 
@@ -202,7 +202,7 @@ def list2table_with_page(title: str, head, data: list, column_keys: dict = None,
     :param head: 表头，支持dict和list ，实例1：{"企业名称": "name"},实例2：[{"企业名称": "name"}]
 
     """
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode_charts包里", DeprecationWarning)
     result = {
         "title": title,
         "columns": [],
