@@ -10,7 +10,7 @@ class Algorithm:
         单向加密算法
         :return:
         """
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         one_way_encryption_algorithm_list = ["MD5", "SHA256", "SHA1", "HMAC"]
         return one_way_encryption_algorithm_list
 
@@ -20,7 +20,7 @@ class Algorithm:
         对称加密算法
         :return:
         """
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         symmetric_encryption_algorithm_list = ["AES", "BASE64", "DES"]
         return symmetric_encryption_algorithm_list
 
@@ -30,13 +30,13 @@ class Algorithm:
         非对称加密算法
         :return:
         """
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         asymmetric_encryption_algorithm_list = ["RSA"]
         return asymmetric_encryption_algorithm_list
 
     @staticmethod
     def get_all_encryption_algorithm():
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         one_way_encryption_algorithm_list = Algorithm.get_one_way_encryption_algorithm_list()
         symmetric_encryption_algorithm_list = Algorithm.get_symmetric_encryption_algorithm_list()
         asymmetric_encryption_algorithm_list = Algorithm.get_asymmetric_encryption_algorithm_list()
@@ -48,7 +48,7 @@ class Algorithm:
 
     @staticmethod
     def encrypt(string: str, algorithm: str, params: dict = {}):
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         all_encryption_algorithm = Algorithm.get_all_encryption_algorithm()
         if algorithm in all_encryption_algorithm:
             algorithm_lib = importlib.import_module(f"lesscode.utils.encryption_algorithm")
@@ -61,7 +61,7 @@ class Algorithm:
 
     @staticmethod
     def decrypt(string: str, algorithm: str, params: dict = {}):
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         symmetric_encryption_algorithm_list = Algorithm.get_symmetric_encryption_algorithm_list()
         asymmetric_encryption_algorithm_list = Algorithm.get_asymmetric_encryption_algorithm_list()
         encryption_algorithm_list = []
