@@ -12,7 +12,7 @@ class AES:
         :param key: 密钥
         :param text: 需要被加密的数据
         """
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         try:
             _AES = importlib.import_module("Cryptodome.Cipher.AES")
         except ImportError as e:
@@ -29,7 +29,7 @@ class AES:
         :param key: 密钥
         :param text: 需要被加密的数据
         """
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         try:
             _AES = importlib.import_module("Cryptodome.Cipher.AES")
         except ImportError as e:
@@ -49,7 +49,7 @@ class AES:
         """
         :param value: 待处理的数据
         """
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         while len(value) % 16 != 0:
             value += '\0'
         return str.encode(value)  # 返回bytes
