@@ -4,22 +4,6 @@ import os
 
 import tornado.options
 
-ks3_connection = None
-ks3_key = None
-ks3_prefix = None
-try:
-    ks3_connection = importlib.import_module("ks3.connection")
-    ks3_key = importlib.import_module("ks3.key")
-    ks3_prefix = importlib.import_module("ks3.prefix")
-except ImportError as e:
-    raise Exception(f"ks3sdk is not exist,run:pip install ks3sdk==1.5.0")
-
-filechunkio = None
-try:
-    filechunkio = importlib.import_module("filechunkio")
-except ImportError as e:
-    raise Exception(f"filechunkio is not exist,run:pip install filechunkio==1.8")
-
 
 class Ks3Oss:
     def __init__(self, **kwargs):
@@ -35,6 +19,10 @@ class Ks3Oss:
         bucket_name = kwargs.pop("bucket_name", None)
         if bucket_name is None:
             bucket_name = tornado.options.options.ks3_connect_config.get("bucket_name")
+        try:
+            ks3_connection = importlib.import_module("ks3.connection")
+        except ImportError:
+            raise Exception(f"ks3sdk is not exist,run:pip install ks3sdk==1.5.0")
         self.client = ks3_connection.Connection(**kwargs)
         if bucket_name is not None:
             self.instance = self.client.get_bucket(bucket_name)
@@ -111,6 +99,11 @@ class Ks3Oss:
         keys = self.instance.list(delimiter=delimiter, **kwargs)
         files = list()
         dirs = list()
+        try:
+            ks3_key = importlib.import_module("ks3.key")
+            ks3_prefix = importlib.import_module("ks3.prefix")
+        except ImportError:
+            raise Exception(f"ks3sdk is not exist,run:pip install ks3sdk==1.5.0")
         for k in keys:
             if isinstance(k, ks3_key.Key):
                 files.append(k.name)
@@ -161,8 +154,12 @@ class Ks3Oss:
         chunk_count = int(math.ceil(file_size * 1.0 / chunk_size * 1.0))
         for i in range(chunk_count):
             offset = chunk_size * i
-            bytes = min(chunk_size, file_size - offset)
-            with filechunkio.FileChunkIO(file_size, 'r', offset=offset, bytes=bytes) as fp:
+            chunk_bytes = min(chunk_size, file_size - offset)
+            try:
+                filechunkio = importlib.import_module("filechunkio")
+            except ImportError:
+                raise Exception(f"filechunkio is not exist,run:pip install filechunkio==1.8")
+            with filechunkio.FileChunkIO(file_size, 'r', offset=offset, bytes=chunk_bytes) as fp:
                 mp.upload_part_from_file(fp, part_num=i + 1)
         ret = mp.complete_upload()
         return ret
