@@ -96,16 +96,24 @@ class BaseHandler(RequestHandler):
 
     @contextmanager
     def make_sqlalchemy_session(self, pool, **kwargs):
-        pool, _ = options.database[pool]
         try:
             sqlalchemy_orm = importlib.import_module("sqlalchemy.orm")
-        except ImportError as e:
+        except ImportError:
             raise Exception(f"sqlalchemy is not exist,run:pip install sqlalchemy==1.4.36")
-        db_session = sqlalchemy_orm.scoped_session(sqlalchemy_orm.sessionmaker(bind=pool, **kwargs))
-        session = db_session()
-        yield session
-        session.commit()
-        session.close()
+        session = None
+        try:
+            db_session = sqlalchemy_orm.scoped_session(sqlalchemy_orm.sessionmaker(bind=pool, **kwargs))
+            session = db_session()
+            yield session
+        except Exception:
+            if session:
+                session.rollback()
+            raise
+        else:
+            session.commit()
+        finally:
+            if session:
+                session.close()
 
     async def get(self):
         """
@@ -402,6 +410,16 @@ class User:
         # 角色id集合
         self.roleIds = None
 
+    def __str__(self):
+        return (f"User(id={self.id},username={self.username},phone_no={self.phone_no},"
+                f"display_name={self.display_name},email={self.email},org_id={self.org_id},"
+                f"account_status={self.account_status},roleIds={self.roleIds})")
+
+    def __repr__(self):
+        return (f"User(id={self.id},username={self.username},phone_no={self.phone_no},"
+                f"display_name={self.display_name},email={self.email},org_id={self.org_id},"
+                f"account_status={self.account_status},roleIds={self.roleIds})")
+
 
 # 解析param
 def parse_val(val, val_type):
