@@ -55,6 +55,8 @@ define("cache_enable", default=False, type=bool, help="redis缓存开关")
 define("task_list", default=[], type=list, help="任务列表")
 define("correction_param", default={"enable": False}, type=dict, help="aes加密key")
 define("sentry_config", default={"enable": False}, type=dict, help="sentry配置")
+define("login_verification_func", default=None, type=object, help="登录验证函数")
+define("cors", default=None, type=dict, help="跨域策略")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
